Authors
=======

This file contains the list of people involved in the development of
pytest-dbfixtures along its history.

* Paweł Wilczyński
* Tomasz Święcicki

Great thanks to `Clearcode <http://clearcode.cc>`_ for allowing releasing
pytest-dbfixtures as free software!
